{#
  Copyright (C) 2022 CERN.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends admin_base_template %}


{% block admin_page_content %}

<div class="ui container dashboard">
  <div class="two column stackable ui grid rel-mt-5 computer tablet only">
    <div class="dashboard-header eight wide column">
      <div class="header">
        <h1>{{ _('Welcome to InvenioRDM Administration')}}</h1>
      </div>
    </div>
    <div class="six wide column ">
      <img class="ui large image"
          src="{{ url_for('static', filename='images/dashboard.png') }}"
          alt=""/>
    </div>
  </div>
  <div class="two column mobile only row">
    <div class="column">
      <div class="header text-align-center">
        <h1>{{ _('Welcome to Invenio Administration')}}</h1>
        <p>{{ _('My managment tool')}}</p>
      </div>
    </div>
    <div class="column">
      <img class="ui large image rel-mt-1"
          src="{{ url_for('static', filename='images/dashboard.png') }}"
          alt=""/>
    </div>
    </div>
  </div>
</div>

{% endblock admin_page_content %}
