{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2022 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- extends "invenio_theme/header_login.html" %}

{%- block profile_admin %}
  {% set ns = namespace(admin_menu=False) %} 
  {%- for item in current_menu.submenu('profile-admin').children if item.visible %}
    {% set ns.admin_menu = True %}
    <a role="menuitem" class="item" href="{{ item.url }}" tabindex="-1">
      {{ item.text|safe }}
    </a>
  {%- endfor %} 
  {% if ns.admin_menu %}
    <div class="ui divider"></div>
  {% endif %}  
{%- endblock %}
